@@ -1,12 +1,12 @@
 /*!
- * Smooth Scroll - v1.4.13 - 2013-11-02
+ * Smooth Scroll - v1.5.0 - 2014-08-11
  * https://github.com/kswedberg/jquery-smooth-scroll
- * Copyright (c) 2013 Karl Swedberg
+ * Copyright (c) 2014 Karl Swedberg
  * Licensed MIT (https://github.com/kswedberg/jquery-smooth-scroll/blob/master/LICENSE-MIT)
  */
 
 (function($) {
-var version = '1.4.13',
+var version = '1.5.0',
     optionOverrides = {},
     defaults = {
       exclude: [],
@@ -34,7 +34,7 @@ var version = '1.4.13',
       speed: 400,
 
       // coefficient for "auto" speed
-      autoCoefficent: 2,
+      autoCoefficient: 2,
 
       // $.fn.smoothScroll only: whether to prevent the default click action
       preventDefault: true
@@ -43,11 +43,11 @@ var version = '1.4.13',
     getScrollable = function(opts) {
       var scrollable = [],
           scrolled = false,
-          dir = opts.dir && opts.dir == 'left' ? 'scrollLeft' : 'scrollTop';
+          dir = opts.dir && opts.dir === 'left' ? 'scrollLeft' : 'scrollTop';
 
       this.each(function() {
 
-        if (this == document || this == window) { return; }
+        if (this === document || this === window) { return; }
         var el = $(this);
         if ( el[dir]() > 0 ) {
           scrollable.push(this);
@@ -68,7 +68,7 @@ var version = '1.4.13',
       // (doing this because Safari sets scrollTop async,
       // so can't set it to 1 and immediately get the value.)
       if (!scrollable.length) {
-        this.each(function(index) {
+        this.each(function() {
           if (this.nodeName === 'BODY') {
             scrollable = [this];
           }
@@ -81,8 +81,7 @@ var version = '1.4.13',
       }
 
       return scrollable;
-    },
-    isTouch = 'ontouchend' in document;
+    };
 
 $.fn.extend({
   scrollable: function(dir) {
@@ -152,6 +151,7 @@ $.fn.extend({
           scrollTarget: thisOpts.scrollTarget || thisHash,
           link: link
         });
+
         $.smoothScroll( clickOpts );
       }
     });
@@ -164,13 +164,12 @@ $.smoothScroll = function(options, px) {
   if ( options === 'options' && typeof px === 'object' ) {
     return $.extend(optionOverrides, px);
   }
-  var opts, $scroller, scrollTargetOffset, speed,
+  var opts, $scroller, scrollTargetOffset, speed, delta,
       scrollerOffset = 0,
       offPos = 'offset',
       scrollDir = 'scrollTop',
       aniProps = {},
-      aniOpts = {},
-      scrollprops = [];
+      aniOpts = {};
 
   if (typeof options === 'number') {
     opts = $.extend({link: null}, $.fn.smoothScroll.defaults, optionOverrides);
@@ -179,13 +178,13 @@ $.smoothScroll = function(options, px) {
     opts = $.extend({link: null}, $.fn.smoothScroll.defaults, options || {}, optionOverrides);
     if (opts.scrollElement) {
       offPos = 'position';
-      if (opts.scrollElement.css('position') == 'static') {
+      if (opts.scrollElement.css('position') === 'static') {
         opts.scrollElement.css('position', 'relative');
       }
     }
   }
 
-  scrollDir = opts.direction == 'left' ? 'scrollLeft' : scrollDir;
+  scrollDir = opts.direction === 'left' ? 'scrollLeft' : scrollDir;
 
   if ( opts.scrollElement ) {
     $scroller = opts.scrollElement;
@@ -211,11 +210,15 @@ $.smoothScroll = function(options, px) {
   // automatically calculate the speed of the scroll based on distance / coefficient
   if (speed === 'auto') {
 
-    // if aniProps[scrollDir] == 0 then we'll use scrollTop() value instead
-    speed = aniProps[scrollDir] || $scroller.scrollTop();
+    // $scroller.scrollTop() is position before scroll, aniProps[scrollDir] is position after
+    // When delta is greater, speed will be greater.
+    delta = aniProps[scrollDir] - $scroller.scrollTop();
+    if(delta < 0) {
+      delta *= -1;
+    }
 
-    // divide the speed by the coefficient
-    speed = speed / opts.autoCoefficent;
+    // Divide the delta by the coefficient
+    speed = delta / opts.autoCoefficient;
   }
 
   aniOpts = {
@@ -239,6 +242,7 @@ $.smoothScroll = function(options, px) {
 
 $.smoothScroll.version = version;
 $.smoothScroll.filterPath = function(string) {
+  string = string || '';
   return string
     .replace(/^\//,'')
     .replace(/(?:index|default).[a-zA-Z]{3,4}$/,'')
@@ -252,4 +256,4 @@ function escapeSelector (str) {
   return str.replace(/(:|\.)/g,'\\$1');
 }
 
-})(jQuery);
\ No newline at end of file
+})(jQuery);
